@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.47 2003/12/08 04:27:10 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.49 2003/12/11 18:07:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -1260,6 +1260,10 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   if (context.link_text_buffer != default_text_buffer)
     G_FREE(context.link_text_buffer);
   G_FREE(args);
+
+#if DEBUG_GUI_MOST
+  fprintf(stderr, "render_bbs_thread() done.\n");
+#endif
 }
 
 
@@ -1282,7 +1286,14 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
       /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
       info = ensure_bbs_thread_info(context->thread);
       info->last_read = bbs_thread_view_create_mark(view);
+#if 0
+      /* ɤॹξϡޡľΥ֤ĴᤷΤǡ
+       * ȥߤ˾ޤ֤ɽƤ롣ʤΤǡٱ
+       * ɬפʤ桼ɤ߻ϤƤ礬¿
+       * Τǡष⡣
+       */
       save_initial_thread_view_position(view, info, info->last_read);
+#endif
     }
   else
     info = NULL;
@@ -1296,8 +1307,11 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 
   if (context->last_read_number == 0)
     {
-      /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
       g_assert(info != NULL);
+      /* save_initial_thread_view_position(...)򤷤ʤȡ
+       * 碌ƥ뤷ƤޤȤΤǡŪ
+       * ƬŽդ롣
+       */
       bbs_thread_view_scroll_to_mark(view, info->last_read);
     }
 
