@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.11 2003/11/29 08:54:28 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.12 2003/12/08 04:27:10 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -69,6 +69,9 @@ typedef struct _BBSThreadGUIInfo
   /* ɽɽ֤դޡ */
   GtkTextMark *next_mark;
 
+  /* ɸɽ֤ޤǳμ¤()뤵뤿idleؿ */
+  guint scroller_id;
+
   /* ġΥ쥹GtkTextBuffer⥪եå */
   guint *offsets;
   guint offsets_length;
