@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.23 2003/12/02 02:28:13 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.25 2003/12/08 04:27:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -42,26 +42,11 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#if ENABLE_REGEXP
-# if HAVE_ONIGURUMA
-#  if HAVE_ONIG_ONIGPOSIX_H
-#    include <onig/onigposix.h>
-#  elif HAVE_ONIGPOSIX_H
-#    include <onigposix.h>
-#  else
-#    error "Use of oniguruma without onig/onigposix.h header isn't considered."
-#  endif
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGPOSIX_H
+#   include <onig/onigposix.h>
 # else
-#  if HAVE_POSIX_REGEX
-#    if HAVE_SYS_TYPES_H
-#      include <sys/types.h>
-#    endif
-#    if HAVE_REGEX_H
-#      include <regex.h>
-#    else
-#      warning "I don't know suitable header file of your posix regex library."
-#    endif
-#  endif
+#   include <onigposix.h>
 # endif
 #endif
 
@@ -466,13 +451,13 @@ bbs_thread_view_init(BBSThreadView *view)
   GtkWidget *widget = GTK_WIDGET(view);
   GtkTextBuffer *buffer = gtk_text_buffer_new(default_tag_table);
 
-  gtk_text_view_set_buffer(&view->text_view, buffer);
+  gtk_text_view_set_buffer(GTK_TEXT_VIEW(view), buffer);
 
   view->text_buffer = buffer;
 
-  gtk_text_view_set_wrap_mode(&view->text_view, GTK_WRAP_CHAR);
-  gtk_text_view_set_editable(&view->text_view, FALSE);
-  gtk_text_view_set_cursor_visible(&view->text_view, FALSE);
+  gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_CHAR);
+  gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);
+  gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(view), FALSE);
 
   g_signal_connect(G_OBJECT(widget), "realize",
 		   G_CALLBACK(text_view_realize_cb), view);
@@ -553,7 +538,7 @@ bbs_thread_view_destroy(GtkObject *object)
       view->search_key = NULL;
     }
 
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   if (view->regexp_available)
     {
       regfree(&view->regexp);
@@ -751,7 +736,7 @@ emit_link_mouse_over(BBSThreadView *view, GdkEventMotion *event)
   if (link == NULL)
     return;
 
-  gdk_window_set_cursor(gtk_text_view_get_window(&view->text_view,
+  gdk_window_set_cursor(gtk_text_view_get_window(GTK_TEXT_VIEW(view),
 						 GTK_TEXT_WINDOW_TEXT),
 			view->hand_cursor);
 
@@ -782,7 +767,7 @@ emit_link_mouse_out(BBSThreadView *view, GdkEventAny *event)
   if (link == NULL)
     return;
 
-  gdk_window_set_cursor(gtk_text_view_get_window(&view->text_view,
+  gdk_window_set_cursor(gtk_text_view_get_window(GTK_TEXT_VIEW(view),
 						 GTK_TEXT_WINDOW_TEXT),
 			view->ibeam_cursor);
 
@@ -1083,7 +1068,7 @@ bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget)
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && GTK_IS_WIDGET(widget));
 
   anchor = gtk_text_buffer_create_child_anchor(view->text_buffer, &view->iter);
-  gtk_text_view_add_child_at_anchor(&view->text_view, widget, anchor);
+  gtk_text_view_add_child_at_anchor(GTK_TEXT_VIEW(view), widget, anchor);
 }
 
 
@@ -1185,12 +1170,12 @@ bbs_thread_view_scroll_to_start(BBSThreadView *view)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
-  buffer = gtk_text_view_get_buffer(&view->text_view);
+  buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(view));
   g_return_if_fail(buffer != NULL);
 
   gtk_text_buffer_get_start_iter(buffer, &iter);
   gtk_text_buffer_place_cursor(buffer, &iter);
-  result = gtk_text_view_scroll_to_iter(&view->text_view,
+  result = gtk_text_view_scroll_to_iter(GTK_TEXT_VIEW(view),
 					&iter, 0.0, FALSE, 0.0, 0.0);
 }
 
@@ -1204,12 +1189,12 @@ bbs_thread_view_scroll_to_end(BBSThreadView *view)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
-  buffer = gtk_text_view_get_buffer(&view->text_view);
+  buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(view));
   g_return_if_fail(buffer != NULL);
 
   gtk_text_buffer_get_end_iter(buffer, &iter);
   gtk_text_buffer_place_cursor(buffer, &iter);
-  result = gtk_text_view_scroll_to_iter(&view->text_view,
+  result = gtk_text_view_scroll_to_iter(GTK_TEXT_VIEW(view),
 					&iter, 0.0, FALSE, 0.0, 0.0);
 }
 
@@ -1224,14 +1209,14 @@ bbs_thread_view_scroll_to_offset(BBSThreadView *view, gint offset)
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_buffer != NULL,
 		       0);
 
-  gtk_text_view_place_cursor_onscreen(&view->text_view);
+  gtk_text_view_place_cursor_onscreen(GTK_TEXT_VIEW(view));
   gtk_text_buffer_get_iter_at_mark(view->text_buffer, &iter,
 				   gtk_text_buffer_get_insert(view->text_buffer));
   previous_offset = gtk_text_iter_get_offset(&iter);
 
   gtk_text_buffer_get_iter_at_offset(view->text_buffer, &iter, offset);
   gtk_text_buffer_place_cursor(view->text_buffer, &iter);
-  result = gtk_text_view_scroll_to_iter(&view->text_view,
+  result = gtk_text_view_scroll_to_iter(GTK_TEXT_VIEW(view),
 					&iter, 0.0, FALSE, 0.0, 0.0);
 
   return previous_offset;
@@ -1252,11 +1237,7 @@ bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark)
   gtk_text_buffer_get_iter_at_mark(buffer, &iter, mark);
   gtk_text_buffer_place_cursor(buffer, &iter);
 
-#if 0	/* XXX: ɤäʡ */
-  gtk_text_view_scroll_to_mark(&view->text_view, mark, 0.3, FALSE, 0.5, 0.5);
-#else
-  gtk_text_view_scroll_to_mark(&view->text_view, mark, 0.3, TRUE, 0.5, 0.5);
-#endif
+  gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(view), mark, 0.2, TRUE, 0.0, 0.2);
 }
 
 
@@ -1301,9 +1282,9 @@ bbs_thread_view_scroll_to_offsets(BBSThreadView *view,
 				     + end_offset);
   gtk_text_buffer_move_mark(view->text_buffer, view->selection_bound_mark,
 			    &iter);
-  gtk_text_view_scroll_mark_onscreen(&view->text_view,
+  gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(view),
 				     view->insert_mark);
-  gtk_text_view_scroll_mark_onscreen(&view->text_view,
+  gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(view),
 				     view->selection_bound_mark);
 }
 
@@ -1317,7 +1298,7 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 {
   gboolean result = FALSE;
   gchar *text;
-#if !ENABLE_REGEXP
+#if !ENABLE_ONIGURUMA
   g_return_val_if_fail(!view->use_regexp, FALSE);
 #endif
   /*
@@ -1352,7 +1333,7 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 
   if (view->use_regexp)
     {
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
       g_assert(view->regexp_available);
 
       if (regexec(&view->regexp, text, 1, view->regexp_match, 0) == 0)
@@ -1401,7 +1382,7 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 {
   gboolean result = FALSE;
   gchar *text;
-#if !ENABLE_REGEXP
+#if !ENABLE_ONIGURUMA
   g_return_val_if_fail(!view->use_regexp, FALSE);
 #endif
   /*
@@ -1421,7 +1402,7 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 
   if (view->use_regexp)
     {
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
       /*
        * MEMO: ɽεսޥåˤϤޤˡ̵ʤΤǡ٤
        *       (ޥåʸ¿)ǰξO(n)regexec()¹Ԥ롣
@@ -1486,7 +1467,7 @@ bbs_thread_view_do_search_forward(BBSThreadView *view,
   gint start_offset = 0;
   gint end_offset = 0;
 
-#if !ENABLE_REGEXP
+#if !ENABLE_ONIGURUMA
   g_return_val_if_fail(!view->use_regexp, FALSE);
 #endif
 
@@ -1537,7 +1518,7 @@ bbs_thread_view_do_search_backward(BBSThreadView *view,
   gint start_offset = 0;
   gint end_offset = 0;
 
-#if !ENABLE_REGEXP
+#if !ENABLE_ONIGURUMA
   g_return_val_if_fail(!view->use_regexp, FALSE);
 #endif
 
@@ -1628,7 +1609,7 @@ bbs_thread_view_find(BBSThreadView *view, const gchar *key,
       view->search_key = NULL;
     }
 
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   if (use_regexp)
     {
       int regcomp_result;
@@ -1738,7 +1719,7 @@ bbs_thread_view_invalidate_search_result(BBSThreadView *view)
       view->search_key = NULL;
     }
 
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   if (view->regexp_available)
     {
       regfree(&view->regexp);
