@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.14 2003/12/02 01:41:13 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.15 2003/12/07 16:57:58 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -33,26 +33,11 @@
 
 #include <gtk/gtk.h>
 
-#if ENABLE_REGEXP
-# if HAVE_ONIGURUMA
-#  if HAVE_ONIG_ONIGPOSIX_H
-#    include <onig/onigposix.h>
-#  elif HAVE_ONIGPOSIX_H
-#    include <onigposix.h>
-#  else
-#    error "Use of oniguruma without onig/onigposix.h header isn't considered."
-#  endif
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGPOSIX_H
+#  include <onig/onigposix.h>
 # else
-#  if HAVE_POSIX_REGEX
-#    if HAVE_SYS_TYPES_H
-#      include <sys/types.h>
-#    endif
-#    if HAVE_REGEX_H
-#      include <regex.h>
-#    else
-#      warning "I don't know suitable header file of your posix regex library."
-#    endif
-#  endif
+#  include <onigposix.h>
 # endif
 #endif
 
@@ -114,7 +99,7 @@ struct _BBSThreadView
 
 
   gchar *search_key;
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   regex_t regexp;
   regmatch_t *regexp_match;
 #endif
