@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.34 2003/12/04 07:32:17 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.35 2003/12/07 16:57:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -49,26 +49,11 @@
 
 #include <errno.h>
 
-#if ENABLE_REGEXP
-# if HAVE_ONIGURUMA
-#  if HAVE_ONIG_ONIGPOSIX_H
-#    include <onig/onigposix.h>
-#  elif HAVE_ONIGPOSIX_H
-#    include <onigposix.h>
-#  else
-#    error "Use of oniguruma without onig/onigposix.h header isn't considered."
-#  endif
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGPOSIX_H
+#  include <onig/onigposix.h>
 # else
-#  if HAVE_POSIX_REGEX
-#    if HAVE_SYS_TYPES_H
-#      include <sys/types.h>
-#    endif
-#    if HAVE_REGEX_H
-#      include <regex.h>
-#    else
-#      warning "I don't know suitable header file of your posix regex library."
-#    endif
-#  endif
+#  include <onigposix.h>
 # endif
 #endif
 
@@ -606,7 +591,7 @@ static ThreadlistSearchQueryData search_query_data =
   NULL,		/* key */
   TEXT_SEARCH_DIRECTION_DOWN,
   NULL,		/* last_view */
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   {},		/* regexp */
   FALSE,	/* regexp_available */
 #endif
@@ -710,7 +695,7 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
   search_query_data.direction = direction;
   search_query_data.enable_wrap = enable_wrap;
   search_query_data.match_case = match_case;
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   search_query_data.use_regexp = use_regexp;
   if (use_regexp)
     {
@@ -1024,6 +1009,20 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
       gdk_threads_enter();
     }
 
+  if (item_view != NULL)
+    {
+      if (paned_notebook->number_of_items_shown == 1)
+	{
+	  PanedNotebook *board_notebook = PANED_NOTEBOOK(item_view);
+	  GtkWidget *threadlist_view
+	    = gtk_bin_get_child(GTK_BIN(board_notebook->selector));
+	  if (gtk_widget_is_focus(threadlist_view))
+	    {
+	      gtk_widget_grab_focus(GTK_WIDGET(application->boardlist_view));
+	    }
+	}
+    }
+
   if (buffer != NULL)
     g_object_unref(G_OBJECT(buffer));
   return;
