@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.67 2003/12/08 04:27:10 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.68 2003/12/11 17:13:41 fuyu Exp $
  */
 
 #include "config.h"
@@ -1143,10 +1143,6 @@ show_threadlist(WorkerThread *employee, gpointer args)
       goto finish_job;
     }
   
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "Updating threadlist.\n");
-#endif
-
   gdk_threads_enter();
   threadlist_view_close(view, cb_args.last_thread);
   gdk_threads_leave();
@@ -1166,7 +1162,13 @@ show_threadlist(WorkerThread *employee, gpointer args)
 	THREAD_LIST_COND_BROADCAST;
       }
     else
-      goto redraw;
+      {
+	cb_args.number_of_threads = 0;
+	cb_args.last_thread = NULL;
+	cb_args.enable_filter = info->enable_filter;
+	cb_args.increment_ignored = TRUE;
+	goto redraw;
+      }
   }
   THREAD_LIST_UNLOCK;
 
@@ -1945,7 +1947,8 @@ write_response(OchushaApplication *application)
   if (view == NULL || thread == NULL)
     return;
 
-  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED)
+  if (thread->flags & (OCHUSHA_BBS_THREAD_DAT_DROPPED
+		       | OCHUSHA_BBS_THREAD_STOPPED))
     return;
 
   if (!ochusha_bbs_thread_is_post_supported(thread))
