@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.42 2003/12/03 12:01:10 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.43 2003/12/07 16:57:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -49,6 +49,14 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGPOSIX_H
+#  include <onig/onigposix.h>
+# else
+#  include <onigposix.h>
+# endif
+#endif
+
 #include <pthread.h>
 
 #include <stdio.h>
@@ -451,7 +459,7 @@ ochusha_init_application(OchushaApplication *application)
 #endif
 #endif	/* ENABLE_MAIN_TOOLBAR */
 
-#if ENABLE_REGEXP && HAVE_ONIGURUMA
+#if ENABLE_ONIGURUMA
   reg_set_encoding(REG_ENCODING_UTF8);
 #endif
 
