@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.21 2003/11/29 08:52:05 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.22 2003/12/08 15:33:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -418,7 +418,10 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
   char *message = NULL;
   const char *bbs;
   char *query = NULL;
-  time_t time;
+  long time;	/* time_tˤ٤10ʿʸؤѴ
+		 * ԤˡʤΤǡ褺longѴƤޤ
+		 * long32bitʥƥˤ2038ǯ()¸ߤ롣
+		 */
   iconv_t converter;
   OchushaUtils2chPostResult post_result;
 
