@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.36 2003/12/08 14:29:35 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.38 2003/12/11 18:06:24 fuyu Exp $
  */
 
 #include "config.h"
@@ -832,6 +832,23 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		    if (each_response_cb != NULL)
 		      result = (*each_response_cb)(thread, i, &response,
 						   callback_data);
+#if 0
+		    /*
+		     * Ƴ()ߤʤΤǡᡣ
+		     */
+		    if (!(thread->flags & OCHUSHA_BBS_THREAD_STOPPED)
+			&& response.date_id != NULL)
+		      {
+			/*
+			 * "\222\342\216\176"""Shift_JISɽ
+			 */
+			if (strcmp(response.date_id, "\222\342\216\176") == 0
+			    || (i > 1000
+				&& strcmp(response.date_id,
+					  "Over 1000 Thread") == 0))
+			  thread->flags |= OCHUSHA_BBS_THREAD_STOPPED;
+		      }
+#else
 		    if (i > 1000
 			&& !(thread->flags & OCHUSHA_BBS_THREAD_STOPPED)
 			&& response.date_id != NULL
@@ -839,6 +856,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		      {
 			thread->flags |= OCHUSHA_BBS_THREAD_STOPPED;
 		      }
+#endif
 		  }
 		else
 		  {
@@ -891,21 +909,55 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 
 	if (interval > 0)
 	  {
+	    /*
+	     * ɤ٤ǡʤ硣
+	     */
+	    unsigned int old_len = buffer->length;
+#if COUNT_FAKE_SIGNAL	/* ¸ */
+	    int wait_count = 0;
+#endif
 	    if (no_wait)
-	      break;
+	      break;	/* ξ */
+
+	    if (ochusha_async_buffer_is_busy(buffer,
+		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses"))
+	      do {
+		if (!ochusha_async_buffer_wait(buffer,
+		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses"))
+		  {
+#if DEBUG_ASYNC_BUFFER_MOST
+		    fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
+#endif
+		    break;
+		  }
+#if COUNT_FAKE_SIGNAL	/* ¸ */
+		wait_count++;
+#endif
+	      } while (buffer->length == old_len && !buffer->fixed);
+
+#if COUNT_FAKE_SIGNAL	/* ¸ */
+	    if (wait_count > 0)
+	      fprintf(stderr, "wait_count=%d\n", wait_count);
+#endif
+	  }
+	else
+	  {
+	    /*
+	     * buffer˥륹åɤsuspend/terminate
+	     * ȿ뤿˥å
+	     */
 	    if (ochusha_async_buffer_is_busy(buffer,
 		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses")
-		&& !ochusha_async_buffer_wait(buffer,
-		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses"))
+		&& (!ochusha_async_buffer_wait(buffer,
+		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses")))
 	      {
-		/* bufferϤ޲٤callerˤޤ */
 #if DEBUG_ASYNC_BUFFER_MOST
 		fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
 #endif
 		break;
 	      }
-	    interval = ANALYSIS_INTERVAL;
 	  }
+	interval = ANALYSIS_INTERVAL;
 
 	if (status->state
 	    == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
