@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.6 2003/12/08 14:29:35 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.9 2003/12/11 18:06:24 fuyu Exp $
  */
 
 #include "config.h"
@@ -656,27 +656,46 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	if (buffer_fixed)
 	  break;
 
-	/*
-	 * XXX: ͥåȥ󥰥åɤĥäƤʤȤˤwaitʤ
-	 *      褦ˤ٤
-	 */
 	if (interval > 0)
 	  {
+	    /*
+	     * ɤ٤ǡʤ硣
+	     */
+	    unsigned int old_len = buffer->length;
 	    if (no_wait)
-	      break;
+	      break;	/* ξ */
+
+	    if (ochusha_async_buffer_is_busy(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
+	      do {
+		if (!ochusha_async_buffer_wait(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
+		  {
+#if DEBUG_ASYNC_BUFFER_MOST
+		    fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
+#endif
+		    break;
+		  }
+	      } while (buffer->length == old_len && !buffer->fixed);
+	  }
+	else
+	  {
+	    /*
+	     * buffer˥륹åɤsuspend/terminate
+	     * ȿ뤿˥å
+	     */
 	    if (ochusha_async_buffer_is_busy(buffer,
 		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses")
-		&& !ochusha_async_buffer_wait(buffer,
-		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
+		&& (!ochusha_async_buffer_wait(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses")))
 	      {
-		/* bufferϤ޲٤callerˤޤ */
 #if DEBUG_ASYNC_BUFFER_MOST
 		fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
 #endif
 		break;
 	      }
-	    interval = ANALYSIS_INTERVAL;
 	  }
+	interval = ANALYSIS_INTERVAL;
 
 	if (status->state
 	    == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
@@ -875,12 +894,17 @@ ochusha_thread_jbbs_make_post_response_message(OchushaThread2ch *thread_2ch,
 					       const char *key,
 					       time_t time)
 {
+  /* time_tΤޤޤˤ٤10ʿʸؤѴ
+   * ԤˡʤΤǡ褺longѴƤޤ
+   * long32bitʥƥˤ2038ǯ()¸ߤ롣
+   */
+  long long_time = time;
   OchushaBBSThread *thread = OCHUSHA_BBS_THREAD(thread_2ch);
 
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-      return g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&NAME=%s&MAIL=%s&MESSAGE=%s&BBS=%s&KEY=%s&TIME=%ld", from, mail, message, bbs, key, time);
+      return g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&NAME=%s&MAIL=%s&MESSAGE=%s&BBS=%s&KEY=%s&TIME=%ld", from, mail, message, bbs, key, long_time);
 
     default:
       return NULL;	/* ̤ݡ */
